pub enum ClientError {
InvalidBaseUrl(String),
InvalidPath(String),
UnknownOperation(String),
MissingPathParameter {
operation_id: String,
parameter: String,
},
Request(Error),
Json(Error),
HttpStatus {
status: StatusCode,
body: String,
},
}Expand description
Error type returned by all client operations. Errors returned by REST client operations.
Variants
InvalidBaseUrl(String)
Base URL is not a valid absolute URL.
InvalidPath(String)
Endpoint path could not be joined to the base URL.
UnknownOperation(String)
The requested OpenAPI operation id is not present in the generated catalog.
MissingPathParameter
A required path template parameter was not provided.
Request(Error)
HTTP transport-layer request failure.
Json(Error)
Response body could not be parsed as JSON.
HttpStatus
Non-success HTTP status with response payload.